@@ -5,14 +5,16 @@ from investing_algorithm_framework.core.portfolio_managers import \
     PortfolioManager, BinancePortfolioManager
 from investing_algorithm_framework.core.order_executors import OrderExecutor, \
     BinanceOrderExecutor
+from investing_algorithm_framework.core.market_services import \
+    MarketService, BinanceMarketService
 from investing_algorithm_framework.core.models import OrderSide, Order, \
-    Position, TimeUnit, db, Portfolio, OrderType
+    Position, TimeUnit, db, Portfolio, OrderType, OrderStatus
 from investing_algorithm_framework.app import App
 from investing_algorithm_framework.globals import current_app
 from investing_algorithm_framework.configuration import Config
 from investing_algorithm_framework.views import *
 
-VERSION = (0, 6, 0, 'alpha', 0)
+VERSION = (0, 7, 0, 'alpha', 0)
 
 __all__ = [
     "App",
@@ -31,5 +33,8 @@ __all__ = [
     "AlgorithmContext",
     "OrderExecutor",
     'BinanceOrderExecutor',
-    "Config"
+    "Config",
+    "MarketService",
+    "BinanceMarketService",
+    "OrderStatus"
 ]
