@@ -3,7 +3,9 @@ from investing_algorithm_framework.configuration.settings import Config
 from investing_algorithm_framework.configuration.validator import \
     ConfigValidator
 from investing_algorithm_framework.configuration.setup import create_app, \
-    setup_config
+    setup_config, setup_database
+from investing_algorithm_framework.configuration.constants import \
+    RESOURCES_DIRECTORY, LOG_LEVEL
 
 BASE_DIR = os.path.dirname(os.path.abspath(__file__))
 
@@ -13,5 +15,8 @@ __all__ = [
     "BASE_DIR",
     "ConfigValidator",
     "create_app",
-    "setup_config"
+    "setup_database",
+    "setup_config",
+    "RESOURCES_DIRECTORY",
+    "LOG_LEVEL"
 ]
