@@ -15,3 +15,11 @@ SQLALCHEMY_DATABASE_URI = 'SQLALCHEMY_DATABASE_URI'
 
 
 BINANCE = "BINANCE"
+
+IDENTIFIER_QUERY_PARAM = "identifier"
+TARGET_SYMBOL_QUERY_PARAM = "target_symbol"
+TRADING_SYMBOL_QUERY_PARAM = "trading_symbol"
+ORDER_SIDE_QUERY_PARAM = "order_side"
+STATUS_QUERY_PARAM = "status"
+POSITION_SYMBOL_QUERY_PARAM = "position"
+SYMBOL_QUERY_PARAM = "symbol"
