@@ -12,6 +12,7 @@ def initialize_db(app: Flask):
     db.init_app(app)
     db.app = app
 
+from investing_algorithm_framework.core.models.order_status import OrderStatus
 from investing_algorithm_framework.core.models.order_type import OrderType
 from investing_algorithm_framework.core.models.order_side import OrderSide
 from investing_algorithm_framework.core.models.time_unit import TimeUnit
@@ -28,5 +29,6 @@ __all__ = [
     'OrderSide',
     "TimeUnit",
     "create_all_tables",
-    "initialize_db"
+    "initialize_db",
+    "OrderStatus"
 ]
