@@ -1,13 +1,16 @@
 from abc import abstractmethod, ABC
 
 from investing_algorithm_framework.core.exceptions import OperationalException
-from investing_algorithm_framework.core.models import Position, Order, \
-    Portfolio, db, OrderType
 from investing_algorithm_framework.core.identifier import Identifier
+from investing_algorithm_framework.core.market_identifier import \
+    MarketIdentifier
+from investing_algorithm_framework.core.models import Position, Order, \
+    Portfolio, db, OrderSide, OrderType, OrderStatus
 
 
-class PortfolioManager(ABC, Identifier):
-    trading_currency = None
+class PortfolioManager(ABC, Identifier, MarketIdentifier):
+    trading_symbol = None
+    market = "test"
 
     @abstractmethod
     def get_initial_unallocated_size(self):
@@ -17,38 +20,43 @@ class PortfolioManager(ABC, Identifier):
         self._initialize_portfolio()
 
     def _initialize_portfolio(self):
-        portfolio = self.get_portfolio()
+        portfolio = self.get_portfolio(False)
 
         if portfolio is None:
             portfolio = Portfolio(
                 identifier=self.identifier,
-                trading_currency=self.trading_currency,
-                unallocated=self.get_initial_unallocated_size()
+                trading_symbol=self.trading_symbol,
+                unallocated=self.get_initial_unallocated_size(),
+                market=self.get_market()
             )
             portfolio.save(db)
 
-    def get_portfolio(self) -> Portfolio:
-        return Portfolio.query.filter_by(
-            identifier=self.identifier,
-            trading_currency=self.trading_currency
-        ).first()
+    def get_portfolio(self, throw_exception=True) -> Portfolio:
+        portfolio = Portfolio.query\
+            .filter_by(identifier=self.identifier)\
+            .first()
+
+        if portfolio is None and throw_exception:
+            raise OperationalException("No portfolio model implemented")
+
+        return portfolio
 
     @property
     def unallocated(self):
         return self.get_portfolio().unallocated
 
-    def get_trading_currency(self) -> str:
+    def get_trading_symbol(self) -> str:
 
-        trading_currency = getattr(self, "trading_currency", None)
+        trading_symbol = getattr(self, "trading_symbol", None)
 
-        if trading_currency is None:
+        if trading_symbol is None:
             raise OperationalException(
-                "Trading currency is not set. Either override "
-                "'get_trading_currency' method or set "
-                "the 'trading_currency' attribute."
+                "Trading symbol is not set. Either override "
+                "'get_trading_symbol' method or set "
+                "the 'trading_symbol' attribute."
             )
 
-        return trading_currency
+        return trading_symbol
 
     def get_positions(
             self,
@@ -57,11 +65,11 @@ class PortfolioManager(ABC, Identifier):
     ):
 
         if symbol is None:
-            query_set = Position.query\
+            query_set = Position.query \
                 .filter_by(portfolio=self.get_portfolio())
         else:
-            query_set = Position.query\
-                .filter_by(portfolio=self.get_portfolio())\
+            query_set = Position.query \
+                .filter_by(portfolio=self.get_portfolio()) \
                 .filter_by(symbol=symbol)
 
         if lazy:
@@ -77,7 +85,7 @@ class PortfolioManager(ABC, Identifier):
 
         if symbol is None:
 
-            query_set = Order.query\
+            query_set = Order.query \
                 .filter(Order.position_id.in_(positions))
         else:
             query_set = Order.query \
@@ -94,7 +102,7 @@ class PortfolioManager(ABC, Identifier):
         if symbol is not None:
             positions = Position.query \
                 .filter_by(portfolio=self.get_portfolio()) \
-                .filter_by(symbol=symbol)\
+                .filter_by(symbol=symbol) \
                 .with_entities(Position.id)
         else:
             positions = Position.query \
@@ -103,33 +111,36 @@ class PortfolioManager(ABC, Identifier):
 
         query_set = Order.query \
             .filter(Order.position_id.in_(positions)) \
-            .filter_by(executed=False)\
+            .filter_by(status=OrderStatus.PENDING.value)
 
         if lazy:
             return query_set
         else:
             return query_set.all()
 
-    def create_buy_order(
+    def create_order(
             self,
             symbol,
-            amount,
-            price=0,
-            order_type=OrderType.LIMIT.value
+            amount=None,
+            price=None,
+            order_type=OrderType.LIMIT.value,
+            order_side=OrderSide.BUY.value,
+            context=None,
+            validate_pair=True,
     ):
-        return self.get_portfolio().create_buy_order(
-            symbol, amount, price, order_type
-        )
 
-    def create_sell_order(
-            self,
+        if context is None:
+            from investing_algorithm_framework import current_app
+            context = current_app.algorithm
+
+        return self.get_portfolio().create_order(
+            context,
+            order_type,
             symbol,
             amount,
-            price=0,
-            order_type=OrderType.LIMIT.value
-    ):
-        return self.get_portfolio().create_sell_order(
-            symbol, amount, price, order_type
+            price,
+            order_side,
+            validate_pair
         )
 
     def add_order(self, order):
